==> nextcloud-27.1.7.tgz: nextcloud/apps/comments/l10n/zh_CN.js <==
OC.L10N.register(
    "comments",
    {
    "Comments" : "评论",
    "You commented" : "你的评论",
    "{author} commented" : "{author} 评论了",
    "You commented on %1$s" : "你在 %1$s 的评论",
    "You commented on {file}" : "你对 {file} 的评论",
    "%1$s commented on %2$s" : "%1$s 评论了 %2$s",
    "{author} commented on {file}" : "{author} 对 {file} 的评论",
    "<strong>Comments</strong> for files" : "文件的<strong>评论</strong>",
    "{user} mentioned you in a comment on \"{file}\"" : "{user} 在 “{file}” 的评论中提到了你",
    "Files app plugin to add comments to files" : "文件应用插件可向文件添加评论",
    "Edit comment" : "编辑评论",
    "Delete comment" : "删除评论",
    "Cancel edit" : "取消编辑",
    "New comment" : "新评论",
    "Post comment" : "发表评论",
    "@ for mentions, : for emoji, / for smart picker" : "使用“@”提及，“:”输入表情符号，“/”唤起智能选择",
    "Could not reload comments" : "无法重载评论",
    "No comments yet, start the conversation!" : "还没有评论，开始对话吧！",
    "No more messages" : "没有更多消息",
    "Retry" : "重试",
    "Failed to mark comments as read" : "无法将评论标记为已读",
    "Unable to load the comments list" : "无法加载评论列表",
    "_1 new comment_::_{unread} new comments_" : ["{unread} 条新评论"],
    "Comment" : "评论",
    "An error occurred while trying to edit the comment" : "编辑评论时出错",
    "Comment deleted" : "评论已删除",
    "An error occurred while trying to delete the comment" : "删除评论时出错",
    "An error occurred while trying to create the comment" : "创建评论时出错",
    "You were mentioned on \"{file}\", in a comment by a user that has since been deleted" : "用户在“ {file}”中的评论中提到了你，此评论已被删除",
    "_%n unread comment_::_%n unread comments_" : ["%n 条未读评论"]
},
"nplurals=1; plural=0;");

==> nextcloud-29.0.5.tgz: nextcloud/apps/comments/l10n/zh_CN.js <==
OC.L10N.register(
    "comments",
    {
    "Comments" : "评论",
    "You commented" : "你的评论",
    "{author} commented" : "{author} 评论了",
    "You commented on %1$s" : "你在 %1$s 的评论",
    "You commented on {file}" : "你对 {file} 的评论",
    "%1$s commented on %2$s" : "%1$s 评论了 %2$s",
    "{author} commented on {file}" : "{author} 对 {file} 的评论",
    "<strong>Comments</strong> for files" : "文件的<strong>评论</strong>",
    "Files" : "文件",
    "You were mentioned on \"{file}\", in a comment by an account that has since been deleted" : "你在文件 “{file}” 内被一个已删除的账号评论提及",
    "{user} mentioned you in a comment on \"{file}\"" : "{user} 在 “{file}” 的评论中提到了你",
    "Files app plugin to add comments to files" : "文件应用插件可向文件添加评论",
    "Edit comment" : "编辑评论",
    "Delete comment" : "删除评论",
    "Cancel edit" : "取消编辑",
    "New comment" : "新评论",
    "Write a comment …" : "发表评论 ...",
    "Post comment" : "发表评论",
    "@ for mentions, : for emoji, / for smart picker" : "使用“@”提及，“:”输入表情符号，“/”唤起智能选择",
    "Could not reload comments" : "无法重载评论",
    "No comments yet, start the conversation!" : "还没有评论，开始对话吧！",
    "No more messages" : "没有更多消息",
    "Retry" : "重试",
    "Failed to mark comments as read" : "无法将评论标记为已读",
    "Unable to load the comments list" : "无法加载评论列表",
    "_1 new comment_::_{unread} new comments_" : ["{unread} 条新评论"],
    "Comment" : "评论",
    "An error occurred while trying to edit the comment" : "编辑评论时出错",
    "Comment deleted" : "评论已删除",
    "An error occurred while trying to delete the comment" : "删除评论时出错",
    "An error occurred while trying to create the comment" : "创建评论时出错",
    "You were mentioned on \"{file}\", in a comment by a user that has since been deleted" : "用户在“ {file}”中的评论中提到了你，此评论已被删除"
},
"nplurals=1; plural=0;");
